@@ -4,7 +4,7 @@
 
 use rbxm_proc::EnumConvert;
 
-/// The [`CFrame`][crate::model::CFrame] that this Instance is relative to
+/// The [`CFrame`](crate::model::CFrame) that this Instance is relative to
 ///
 /// **Reference Link**: [enum/ActuatorRelativeTo](https://developer.roblox.com/en-us/api-reference/enum/ActuatorRelativeTo)
 #[derive(Debug, Copy, Clone, EnumConvert)]
@@ -22,7 +22,7 @@ pub enum ActuatorRelativeTo {
 /// **Reference Link**: [enum/ActuatorType](https://developer.roblox.com/en-us/api-reference/enum/ActuatorType)
 #[derive(Debug, Copy, Clone, EnumConvert)]
 pub enum ActuatorType {
-    /// No actuation
+    /// No actuati,on
     None = 0,
     /// Motor actuation
     Motor = 1,
@@ -78,6 +78,13 @@ pub enum AnimationPriority {
     Core = 1000,
 }
 
+#[derive(Debug, Copy, Clone, EnumConvert)]
+pub enum AnimatorRetargetingMode {
+    Default = 0,
+    Disabled = 1,
+    Enabled = 2,
+}
+
 /// How to apply this UI stroke
 ///
 /// **Reference Link**: [enum/ApplyStrokeMode](https://developer.roblox.com/en-us/api-reference/enum/ApplyStrokeMode)
@@ -128,7 +135,6 @@ pub enum Axis {
     Z = 2,
 }
 
-///
 #[derive(Debug, Copy, Clone, EnumConvert)]
 pub enum BinType {
     Script = 0,
@@ -155,6 +161,12 @@ pub enum BorderMode {
     Inset = 2,
 }
 
+impl Default for BorderMode {
+    fn default() -> Self {
+        BorderMode::Outline
+    }
+}
+
 #[derive(Debug, Copy, Clone, EnumConvert)]
 pub enum ButtonStyle {
     Custom = 0,
@@ -177,6 +189,13 @@ pub enum CameraType {
     Orbital = 7,
 }
 
+#[derive(Debug, Copy, Clone, EnumConvert)]
+pub enum ClientAnimatorThrottlingMode {
+    Default = 0,
+    Disabled = 1,
+    Enabled = 2,
+}
+
 #[derive(Debug, Copy, Clone, EnumConvert)]
 pub enum DialogBehaviorType {
     SinglePlayer = 0,
@@ -353,6 +372,13 @@ pub enum HumanoidHealthDisplayType {
     AlwaysOff = 2,
 }
 
+#[derive(Debug, Copy, Clone, EnumConvert)]
+pub enum HumanoidOnlySetCollisionsOnStateChange {
+    Default = 0,
+    Disabled = 1,
+    Enabled = 2,
+}
+
 #[derive(Debug, Copy, Clone, EnumConvert)]
 pub enum HumanoidRigType {
     R6 = 0,
@@ -373,6 +399,19 @@ pub enum InputType {
     Sin = 13,
 }
 
+impl Default for InputType {
+    fn default() -> Self {
+        InputType::NoInput
+    }
+}
+
+#[derive(Debug, Copy, Clone, EnumConvert)]
+pub enum InterpolationThrottlingMode {
+    Default = 0,
+    Disabled = 1,
+    Enabled = 2,
+}
+
 #[derive(Debug, Copy, Clone, EnumConvert)]
 pub enum KeyCode {
     Unknown = 0,
@@ -693,6 +732,19 @@ pub enum Material {
     Water = 2048,
 }
 
+impl Default for Material {
+    fn default() -> Self {
+        Material::Plastic
+    }
+}
+
+#[derive(Debug, Copy, Clone, EnumConvert)]
+pub enum MeshPartHeadsAndAccessories {
+    Default = 0,
+    Disabled = 1,
+    Enabled = 2,
+}
+
 #[derive(Debug, Copy, Clone, EnumConvert)]
 pub enum MeshType {
     Head = 0,
@@ -716,6 +768,12 @@ pub enum ModelLevelOfDetail {
     Disabled = 2,
 }
 
+impl Default for ModelLevelOfDetail {
+    fn default() -> Self {
+        ModelLevelOfDetail::Automatic
+    }
+}
+
 #[derive(Debug, Copy, Clone, EnumConvert)]
 pub enum NameOcclusion {
     NoOcclusion = 0,
@@ -723,6 +781,13 @@ pub enum NameOcclusion {
     OccludeAll = 2,
 }
 
+#[derive(Debug, Copy, Clone, EnumConvert)]
+pub enum NewAnimationRuntimeSettings {
+    Default = 0,
+    Disabled = 1,
+    Enabled = 2,
+}
+
 #[derive(Debug, Copy, Clone, EnumConvert)]
 pub enum NormalId {
     Right = 0,
@@ -748,6 +813,20 @@ pub enum PartType {
     Cylinder = 2,
 }
 
+#[derive(Debug, Copy, Clone, EnumConvert)]
+pub enum PhysicsSimulationRate {
+    Fixed240Hz = 0,
+    Fixed120Hz = 1,
+    Fixed60Hz = 2,
+}
+
+#[derive(Debug, Copy, Clone, EnumConvert)]
+pub enum PhysicsSteppingMethod {
+    Default = 0,
+    Fixed = 1,
+    Adaptive = 2,
+}
+
 #[derive(Debug, Copy, Clone, EnumConvert)]
 pub enum PoseEasingDirection {
     In = 0,
@@ -790,6 +869,12 @@ pub enum RenderingTestComparisonMethod {
     Diff = 1,
 }
 
+#[derive(Debug, Copy, Clone, EnumConvert)]
+pub enum ResamplerMode {
+    Default = 0,
+    Pixelated = 1,
+}
+
 #[derive(Debug, Copy, Clone, EnumConvert)]
 pub enum RollOffMode {
     Inverse = 0,
@@ -821,6 +906,13 @@ pub enum ScrollingDirection {
     XY = 4,
 }
 
+#[derive(Debug, Copy, Clone, EnumConvert)]
+pub enum SignalBehavior {
+    Default = 0,
+    Immediate = 1,
+    Deferred = 2,
+}
+
 #[derive(Debug, Copy, Clone, EnumConvert)]
 pub enum SizeConstraint {
     RelativeXY = 0,
@@ -843,6 +935,20 @@ pub enum StartCorner {
     BottomRight = 3,
 }
 
+#[derive(Debug, Copy, Clone, EnumConvert)]
+pub enum StreamingPauseMode {
+    Default = 0,
+    Disabled = 1,
+    ClientPhysicsPause = 2,
+}
+
+#[derive(Debug, Copy, Clone, EnumConvert)]
+pub enum StreamOutBehavior {
+    Default = 0,
+    LowMemory = 1,
+    Opportunistic = 2,
+}
+
 #[derive(Debug, Copy, Clone, EnumConvert)]
 pub enum SurfaceGuiSizingMode {
     FixedSize = 0,
@@ -863,12 +969,27 @@ pub enum SurfaceType {
     SmoothNoOutlines = 10,
 }
 
+impl Default for SurfaceType {
+    fn default() -> Self {
+        SurfaceType::Smooth
+    }
+}
+
 #[derive(Debug, Copy, Clone, EnumConvert)]
 pub enum TableMajorAxis {
     RowMajor = 0,
     ColumnMajor = 1,
 }
 
+#[derive(Debug, Copy, Clone, EnumConvert)]
+pub enum Technology {
+    Legacy = 0,
+    Voxel = 1,
+    Compatibility = 2,
+    ShadowMap = 3,
+    Future = 4,
+}
+
 #[derive(Debug, Copy, Clone, EnumConvert)]
 pub enum TerrainAcquisitionMethod {
     None = 0,
